@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: display.ml,v 1.32 2004/09/24 10:55:05 weis Exp $ *)
+(* $Id: display.ml,v 1.33 2006/03/14 05:28:58 furuse Exp $ *)
 
 open Livmisc;;
 open Color;;
@@ -88,7 +88,7 @@ class win = object
     set_timeout ()
 
   initializer
-    window#event#connect#configure ~callback:
+    ignore (window#event#connect#configure ~callback:
       (fun ev ->
          let w = GdkEvent.Configure.width ev
          and h = GdkEvent.Configure.height ev in
@@ -99,8 +99,7 @@ class win = object
            let w', h' = Drawable.get_size window#misc#window in
            if (w', h') <> (w, h) then f w' h' in
          f w h;
-         false);
-    ()
+         false))
 end;;
 
 let root_pixmap =
