@@ -12,7 +12,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: test.ml,v 1.30 2004/09/27 15:34:07 weis Exp $ *)
+(* $Id: test.ml,v 1.31 2007/01/18 10:53:44 rousse Exp $ *)
 
 open Images;;
 open Format;;
@@ -43,7 +43,9 @@ let draw_string =
   if Camlimages.lib_freetype then begin
     (* Freetype library initialization *)
     let library = Freetype.init () in
-    let face, face_info = Freetype.new_face library "micap.ttf" 0 in
+    let src_dir = (try Sys.getenv "srcdir" with Not_found -> ".") in
+    let src_file = Filename.concat src_dir "micap.ttf" in
+    let face, face_info = Freetype.new_face library src_file 0 in
     Freetype.set_char_size face 18.0 18.0 72 72;
 
     fun str x y ->
@@ -87,7 +89,10 @@ let images =
   Arg.parse [] (fun x -> images := x :: !images) "test images";
   if !images <> []
   then List.rev !images
-  else List.map (fun x -> Filename.concat "images" x) images_default;;
+  else 
+    let src_dir = (try Sys.getenv "srcdir" with Not_found -> ".") in
+    let images_src_dir = Filename.concat src_dir "images" in
+    List.map (fun x -> Filename.concat images_src_dir x) images_default;;
 
 open Gif;;
 
